# Changelog

[1.0.0]

- initial release

[1.1.0]

- update `jwt-auth` to have `openapi_components` and `security_requirements` properties that can be used for OpenAPI 3.1 docs generation.
- Use `cryptography` as `python-jose` backend
- Adjustments to `Token` model.
